@@ -8,28 +8,35 @@ bool ConfigFile::nextLine(istream &istr, string &line)
     {
         ++d_rawIndex;                               // at the next line
 
+                                                    // remove initial ws.
         string::size_type pos = line.find_first_not_of(" \t");
-        if (pos != string::npos)                    // remove initial ws.
+        if (pos != string::npos)
             line.erase(0, pos);
 
         if (d_rmComment)
             removeComment(line);
 
+                                                    // process lines ending
+                                                    // in a backslash
         n_continuations = 0;
-        while (true)
-        {
-            size_t lastChar = line.length() - 1;   // the last char
+        while (size_t lastIdx = line.length())      // as long as there are
+        {                                           // characters
+
+            --lastIdx;                              // set lastIdx to idx of 
+                                                    // last ch.
     
-            if (line[lastChar] != '\\')             // not '\\' ?
+            if (line[lastIdx] != '\\')              // last not \ ?
                 break;                              // then done here
                               
                                                     // got line continuation...
-            line.erase(lastChar);                   // erase the last char
+
+            line.resize(lastIdx);                   // erase the last char
+
                                                     // append the next line
             n_continuations += append_next(istr, line);
         }
 
-        if (hasContent(line))                       // any content on this?
+        if (hasContent(line))                       // any contents on this?
         {
             removeTrailingBlanks(line);
 
@@ -39,6 +46,7 @@ bool ConfigFile::nextLine(istream &istr, string &line)
             return true;
         }
     }
+
     line.erase();
     return false;                       // no more lines
 }   
