@@ -16,6 +16,12 @@ EncryptBufImp::EncryptBufImp(ostream &outStream, string const &ivv,
 
         IRandStream irs(0, 255, time(0));
 
-        for_each(iv.begin(), iv.end(), FnWrap::unary(setChar, irs));
+        for_each(
+            iv.begin(), iv.end(), 
+            [&](char &ch)
+            {
+                setChar(ch, irs);
+            }
+        );
     }
 }
