@@ -13,12 +13,17 @@ void Process::childProcess()
         ec.args[2] = d_command.c_str();
         ec.args[3] = 0;
     }
+
+#ifdef BOBCAT_DIY_CLOEXEC_
+    if (d_closedByChild != 0)
+        close(d_closedByChild);
+#endif
                           
     (*(d_processType == USE_PATH ? execvp : execv))
         (ec.args[0], const_cast<char * const *>(ec.args));
 
-    throw Errno("Process: ") << insertable << " cannot execv[p] " << 
-                                                d_command << throwable;
+    throw Errno("Process: ") << " cannot execv[p] " << d_command;
+
 }
 
 //    std::cerr << "ChildProcess starts as:\n";
@@ -26,3 +31,9 @@ void Process::childProcess()
 //        std::cerr << "  " << *cp << endl;
 //    std::cerr << "======================\n";
 
+
+
+
+
+
+
