@@ -4,9 +4,9 @@ Process::Process(iomode mode, std::string const &command)
 :
     d_command(command),
 
-    d_childCin(0),
-    d_childCout(0),
-    d_childCerr(0)
+    d_oChildIn(0),
+    d_iChildOut(0),
+    d_iChildErr(0)
 {
     initialize(0, mode, NO_PATH);
 }
