@@ -10,7 +10,7 @@ void Process::start(iomode mode, ProcessType type, size_t timeLimit)
     d_processType = type;
 
     sanitizeIOMode(mode);
-    setPipes();
+    newPipes();
 
     if (d_command[0] == '`' && *d_command.rbegin() == '`')  // rm backticks
         d_command = d_command.substr(1, d_command.length() - 2);
