@@ -1,6 +1,6 @@
 #include "string.ih"
 
-size_t String::split(std::vector<std::string> *words, 
+size_t String::split(std::vector<string> *words, 
                 string const &str, char const *sep, bool addEmpty)
 {
     words->clear();
